@@ -13,6 +13,7 @@ from .validators import (
 
 VALID_ELASTICINFERENCEACCELERATOR_TYPES = ('eia1.medium', 'eia1.large',
                                            'eia1.xlarge')
+VALID_CLIENTVPNENDPOINT_VPNPORT = (443, 1194)
 
 
 def validate_elasticinferenceaccelerator_type(
@@ -25,6 +26,15 @@ def validate_elasticinferenceaccelerator_type(
     return elasticinferenceaccelerator_type
 
 
+def validate_clientvpnendpoint_vpnport(vpnport):
+    """Validate VpnPort for ClientVpnEndpoint"""
+
+    if vpnport not in VALID_CLIENTVPNENDPOINT_VPNPORT:
+        raise ValueError("ClientVpnEndpoint VpnPortmust be one of: %s" %  # NOQA
+                         ", ".join(VALID_CLIENTVPNENDPOINT_VPNPORT))
+    return vpnport
+
+
 class Tag(AWSProperty):
     props = {
         'Key': (str, True),
@@ -138,8 +148,17 @@ class BlockDeviceMapping(AWSProperty):
     props = {
         'DeviceName': (str, True),
         'Ebs': (EBSBlockDevice, False),  # Conditional
-        'NoDevice': (dict, False),
         'VirtualName': (str, False),  # Conditional
+        'NoDevice': (dict, False)
+    }
+
+
+class LaunchTemplateBlockDeviceMapping(AWSProperty):
+    props = {
+        'DeviceName': (str, True),
+        'Ebs': (EBSBlockDevice, False),  # Conditional
+        'VirtualName': (str, False),  # Conditional
+        'NoDevice': (str, False)
     }
 
 
@@ -156,6 +175,8 @@ class Placement(AWSProperty):
         'AvailabilityZone': (str, False),
         'GroupName': (str, False),
         'HostId': (str, False),
+        'HostResourceGroupArn': (str, False),
+        'PartitionNumber': (integer, False),
         'Tenancy': (str, False)
     }
 
@@ -232,6 +253,15 @@ class SsmAssociations(AWSProperty):
     }
 
 
+class GatewayRouteTableAssociation(AWSObject):
+    resource_type = "AWS::EC2::GatewayRouteTableAssociation"
+
+    props = {
+        'GatewayId': (str, True),
+        'RouteTableId': (str, True),
+    }
+
+
 class Host(AWSObject):
     resource_type = "AWS::EC2::Host"
 
@@ -245,6 +275,7 @@ class Host(AWSObject):
 
 class ElasticInferenceAccelerator(AWSProperty):
     props = {
+        'Count': (integer, False),
         'Type': (validate_elasticinferenceaccelerator_type, True),
     }
 
@@ -255,6 +286,12 @@ class LicenseSpecification(AWSProperty):
     }
 
 
+class HibernationOptions(AWSProperty):
+    props = {
+        'Configured': (boolean, False),
+    }
+
+
 class Instance(AWSObject):
     resource_type = "AWS::EC2::Instance"
 
@@ -268,7 +305,9 @@ class Instance(AWSObject):
         'EbsOptimized': (boolean, False),
         'ElasticGpuSpecifications': ([ElasticGpuSpecification], False),
         'ElasticInferenceAccelerators': ([ElasticInferenceAccelerator], False),
+        'HibernationOptions': (HibernationOptions, False),
         'HostId': (str, False),
+        'HostResourceGroupArn': (str, False),
         'IamInstanceProfile': (str, False),
         'ImageId': (str, False),
         'InstanceInitiatedShutdownBehavior': (str, False),
@@ -910,7 +949,7 @@ class PlacementGroup(AWSObject):
     resource_type = "AWS::EC2::PlacementGroup"
 
     props = {
-        'Strategy': (str, True),
+        'Strategy': (str, False),
     }
 
 
@@ -963,14 +1002,30 @@ class LaunchTemplateCreditSpecification(AWSProperty):
     }
 
 
+class MetadataOptions(AWSProperty):
+    props = {
+        'HttpEndpoint': (str, False),
+        'HttpPutResponseHopLimit': (integer, False),
+        'HttpTokens': (str, False),
+    }
+
+
+class LaunchTemplateElasticInferenceAccelerator(AWSProperty):
+    props = {
+        'Count': (integer, False),
+        'Type': (validate_elasticinferenceaccelerator_type, False),
+    }
+
+
 class LaunchTemplateData(AWSProperty):
     props = {
-        'BlockDeviceMappings': ([BlockDeviceMapping], False),
+        'BlockDeviceMappings': ([LaunchTemplateBlockDeviceMapping], False),
         'CpuOptions': (CpuOptions, False),
         'CreditSpecification': (LaunchTemplateCreditSpecification, False),
         'DisableApiTermination': (boolean, False),
         'EbsOptimized': (boolean, False),
         'ElasticGpuSpecifications': ([ElasticGpuSpecification], False),
+        'ElasticInferenceAccelerators': ([LaunchTemplateElasticInferenceAccelerator], False),  # NOQA
         'IamInstanceProfile': (IamInstanceProfile, False),
         'ImageId': (str, False),
         'InstanceInitiatedShutdownBehavior': (str, False),
@@ -979,6 +1034,7 @@ class LaunchTemplateData(AWSProperty):
         'KernelId': (str, False),
         'KeyName': (str, False),
         'LicenseSpecifications': ([LicenseSpecification], False),
+        'MetadataOptions': (MetadataOptions, False),
         'Monitoring': (Monitoring, False),
         'NetworkInterfaces': ([NetworkInterfaces], False),
         'Placement': (Placement, False),
@@ -1255,6 +1311,7 @@ class ClientVpnEndpoint(AWSObject):
         'SplitTunnel': (boolean, False),
         'TagSpecifications': ([TagSpecifications], False),
         'TransportProtocol': (str, False),
+        'VpnPort': (validate_clientvpnendpoint_vpnport, False),
     }
 
 
@@ -1276,3 +1333,23 @@ class ClientVpnTargetNetworkAssociation(AWSObject):
         'ClientVpnEndpointId': (str, True),
         'SubnetId': (str, True),
     }
+
+
+class LocalGatewayRoute(AWSObject):
+    resource_type = "AWS::EC2::LocalGatewayRoute"
+
+    props = {
+        'DestinationCidrBlock': (str, True),
+        'LocalGatewayRouteTableId': (str, True),
+        'LocalGatewayVirtualInterfaceGroupId': (str, True),
+    }
+
+
+class LocalGatewayRouteTableVPCAssociation(AWSObject):
+    resource_type = "AWS::EC2::LocalGatewayRouteTableVPCAssociation"
+
+    props = {
+        'LocalGatewayRouteTableId': (str, True),
+        'Tags': ((Tags, list), False),
+        'VpcId': (str, True),
+    }
